pub struct ImplementingPath {
pub path: String,
pub source: TraceSource,
}Expand description
A path claimed by a spec, with its linkage source.
Fields
path: Stringsource: TraceSourceTrait Implementations
Sourceimpl Clone for ImplementingPath
impl Clone for ImplementingPath
Sourcefn clone(&self) -> ImplementingPath
fn clone(&self) -> ImplementingPath
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImplementingPath
impl Debug for ImplementingPath
Sourceimpl<'de> Deserialize<'de> for ImplementingPath
impl<'de> Deserialize<'de> for ImplementingPath
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ImplementingPath
Sourceimpl PartialEq for ImplementingPath
impl PartialEq for ImplementingPath
Sourcefn eq(&self, other: &ImplementingPath) -> bool
fn eq(&self, other: &ImplementingPath) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ImplementingPath
impl Serialize for ImplementingPath
impl StructuralPartialEq for ImplementingPath